@@ -5,10 +5,16 @@ __all__ = [
     'ExplainerComponent',
     'PosLabelSelector',
     'GraphPopout',
+    'IndexSelector',
     'make_hideable',
     'get_dbc_tooltips',
     'update_params',
     'update_kwargs',
+    'encode_callables',
+    'decode_callables',
+    'reset_id_generator',
+    'yield_id',
+    'get_local_ip_adress',
     'instantiate_component'
 ]
 
@@ -16,6 +22,10 @@ import sys
 from abc import ABC
 import inspect
 import types
+from typing import Union, List, Tuple
+from pathlib import Path
+from importlib import import_module
+import socket
 
 import dash
 import dash_core_components as dcc
@@ -23,7 +33,7 @@ import dash_bootstrap_components as dbc
 import dash_html_components as html
 from dash.dependencies import Input, Output, State
 
-import shortuuid
+from . import to_html
 
 # Stolen from https://www.fast.ai/2019/08/06/delegation/
 # then extended to deal with multiple inheritance
@@ -79,32 +89,97 @@ def update_kwargs(kwargs, **params):
     return dict(kwargs, **params)
 
 
+def encode_callables(obj):
+    """replaces all callables (functions) in obj with a dict specifying module and name
+    
+    Works recursively through sub-list and sub-dicts"""
+    if callable(obj):
+        return dict(__callable__=dict(module=obj.__module__, name=obj.__name__))  
+    if isinstance(obj, dict):
+        return {k:encode_callables(v) for k, v in obj.items()}
+    elif isinstance(obj, list):
+        return [encode_callables(o) for o in obj]     
+    return obj
+
+
+def decode_callables(obj):
+    """replaces all dict-encoded callables in obj with the appropriate function
+    
+    Works recursively through sub-list and sub-dicts"""
+    if isinstance(obj, dict) and '__callable__' in obj:
+        return getattr(import_module(obj['__callable__']['module']), obj['__callable__']['name'])
+    if isinstance(obj, dict):
+        return {k:decode_callables(v) for k, v in obj.items()}
+    elif isinstance(obj, list):
+        return [decode_callables(o) for o in obj]     
+    return obj
+
+def id_generator(prefix='id', start=0):
+    """generator that generatores unique consecutive id's starting with 'id' + number
+    
+    Can be reset with reset_id_generator()"""
+    i = start
+    while True:
+        yield prefix+str(i), i
+        i += 1
+
+def reset_id_generator(prefix='id', start=0):
+    """resets the global id generator"""
+    global id_gen
+    id_gen = id_generator(prefix, start)
+
+def yield_id(return_i=False):
+    """yields the next unique consecutive id. Reset using reset_id_generator()"""
+    global id_gen
+    str_id, i = next(id_gen)
+    if return_i:
+        return str_id, i
+    return str_id
+    
+
+reset_id_generator()
+
+
+def get_local_ip_adress():
+    """returns the local ip adress"""
+    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    try:
+        # doesn't even have to be reachable
+        s.connect(('10.255.255.255', 1))
+        IP = s.getsockname()[0]
+    except Exception:
+        IP = '127.0.0.1'
+    finally:
+        s.close()
+    return IP
+
+
 def get_dbc_tooltips(dbc_table, desc_dict, hover_id, name):
-                """Return a dbc.Table and a list of dbc.Tooltips.
+    """Return a dbc.Table and a list of dbc.Tooltips.
 
-                Args:
-                    dbc_table (dbc.Table): Table with first column consisting of label
-                    desc_dict (dict): dict that map labels to a description (str)
-                    hover_id (str): dash component_id base: tooltips will have 
-                        component_id=f"{hover_id}-{label}-{name}"
-                    name (str): name to be used in hover_id
+    Args:
+        dbc_table (dbc.Table): Table with first column consisting of label
+        desc_dict (dict): dict that map labels to a description (str)
+        hover_id (str): dash component_id base: tooltips will have 
+            component_id=f"{hover_id}-{label}-{name}"
+        name (str): name to be used in hover_id
 
-                Returns:
-                    dbc.Table, List[dbc.Tooltip]
-                """
-                tooltips_dict = {}
-                for tr in dbc_table.children[1].children:
-                    tds = tr.children
-                    label = tds[0].children
-                    if label in desc_dict:
-                        tr.id = f'{hover_id}-{label}-'+name
-                        tooltips_dict[label] = desc_dict[label]
+    Returns:
+        dbc.Table, List[dbc.Tooltip]
+    """
+    tooltips_dict = {}
+    for tr in dbc_table.children[1].children:
+        tds = tr.children
+        label = tds[0].children
+        if label in desc_dict:
+            tr.id = f'{hover_id}-{label}-'+name
+            tooltips_dict[label] = desc_dict[label]
 
-                tooltips = [dbc.Tooltip(desc,
-                    target=f'{hover_id}-{label}-'+name, 
-                    placement="top") for label, desc in tooltips_dict.items()]
+    tooltips = [dbc.Tooltip(desc,
+        target=f'{hover_id}-{label}-'+name, 
+        placement="top") for label, desc in tooltips_dict.items()]
 
-                return dbc_table, tooltips
+    return dbc_table, tooltips
 
 
 def make_hideable(element, hide=False):
@@ -164,6 +239,9 @@ class ExplainerComponent(ABC):
         ExplainerComponent will register callbacks of subcomponents in addition
         to component_callbacks() when calling register_callbacks()
     """
+    
+    _state_props = {}
+    
     def __init__(self, explainer, title=None, name=None):
         """initialize the ExplainerComponent
 
@@ -177,7 +255,7 @@ class ExplainerComponent(ABC):
         """
         self._store_child_params(no_param=['explainer'])
         if not hasattr(self, "name") or self.name is None:
-            self.name = name or "uuid"+shortuuid.ShortUUID().random(length=5)
+            self.name = name or yield_id()
         if not hasattr(self, "title") or self.title is None:
             self.title = title or "Custom"
 
@@ -212,6 +290,8 @@ class ExplainerComponent(ABC):
                 setattr(self, name, value)
             if not dont_param and name not in no_store and name not in no_param:
                 self._stored_params[name] = value
+        
+        self._stored_params = encode_callables(self._stored_params)
 
     def exclude_callbacks(self, *components):
         """exclude certain subcomponents from the register_components scan
@@ -304,7 +384,32 @@ class ExplainerComponent(ABC):
         for comp in self._components:
             _component_imports.extend(comp.component_imports)
         return list(set(_component_imports))
-
+    
+    def get_state_tuples(self):
+        """returns a list of State (id, property) tuples for the component and all subcomponents"""
+        self.register_components()
+        for key, tup in self._state_props.items():
+            if not isinstance(tup, tuple) or len(tup) != 2 or not isinstance(tup[0], str) or not isinstance(tup[1], str):
+                raise ValueError(f"Expected a (id:str, property:str) tuple but {self} has _state_props['{key}'] == {tup}")
+        _state_tuples = [(id_+self.name, prop_) for id_, prop_ in self._state_props.values()]
+        for comp in self._components:
+            _state_tuples.extend(comp.get_state_tuples())
+        return sorted(list(set(_state_tuples)))
+    
+    def get_state_args(self, state_dict=None):
+        """returns _state_dict with correct self.name attached
+        if state_dict is passed then replace the state_id_prop_tuples with their values
+        from state_dict or else as a property.
+        """
+        state_tuples = {k:(v[0]+self.name, v[1]) for k, v in self._state_props.items()}
+        state_args = {}
+        state_dict = state_dict or {}
+        for param, (id_, prop_) in state_tuples.items():
+            if (id_, prop_) in state_dict:
+                state_args[param] = state_dict[(id_, prop_)]
+            elif hasattr(self, param):
+                state_args[param] = getattr(self, param)
+        return state_args
 
     @property
     def pos_labels(self):
@@ -340,6 +445,27 @@ class ExplainerComponent(ABC):
         """layout to be defined by the particular ExplainerComponent instance.
         All element id's should append +self.name to make sure they are unique."""
         return None
+      
+    def to_html(self, state_dict:dict=None, add_header:bool=True):
+        """return static html for this component and all subcomponents. 
+        
+        Args:
+            state_dict (dict): dictionary with id_prop_tuple as keys and state as value.
+        """
+        html = to_html.div("")
+        if add_header:
+            return to_html.add_header(html)
+        return html
+
+    def save_html(self, filename:Union[str, Path]): # noqa: E821
+        """Store output of to_html to a file
+
+        Args:
+            filename (str, Path): filename to store html
+        """
+        html = self.to_html(add_header=True)
+        with open(filename, "w") as file:
+            file.write(html)
 
     def component_callbacks(self, app):
         """register callbacks specific to this ExplainerComponent."""
@@ -385,23 +511,63 @@ class PosLabelSelector(ExplainerComponent):
     def layout(self):
         if self.explainer.is_classifier:
             return html.Div([
-                    dbc.Label("Positive class:", 
-                        html_for="pos-label-"+self.name, 
-                        id="pos-label-label-"+self.name),
-                    dbc.Tooltip("Select the label to be set as the positive class",
-                        target="pos-label-label-"+self.name),
-                    dcc.Dropdown(
-                        id='pos-label-'+self.name,
-                        options = [{'label': label, 'value': i}
-                                for i, label in enumerate(self.explainer.labels)],
-                        value = self.pos_label,
-                        clearable=False,
+                    html.Div([
+                        dbc.Label("Positive class:", 
+                            html_for="pos-label-"+self.name, 
+                            id="pos-label-label-"+self.name,
+                            style = {"font-size":"16"},
+                        ),
+                        dbc.Tooltip("Select the label to be set as the positive class",
+                            target="pos-label-label-"+self.name),
+                    ]),
+                    html.Div([
+                        dcc.Dropdown(
+                            id='pos-label-'+self.name,
+                            options = [{'label': label, 'value': i}
+                                    for i, label in enumerate(self.explainer.labels)],
+                            value = self.pos_label,
+                            optionHeight=24,
+                            clearable=False,
+                            style={'height': '24', 'font-size': '24',}
                         )
+                    ]),   
             ])
         else:
             return html.Div([dcc.Input(id="pos-label-"+self.name)], style=dict(display="none"))
 
 
+class IndexSelector(ExplainerComponent):
+    """Either shows a dropdown or a free text input field for selecting an index"""
+    def __init__(self, explainer, name=None, index=None, index_dropdown=True):
+        super().__init__(explainer)
+        
+    def layout(self):
+        if self.index_dropdown:
+            return dcc.Dropdown(id=self.name, 
+                                options = [{'label': str(idx), 'value': str(idx)} for idx in self.explainer.get_index_list()],
+                                placeholder=f"Select {self.explainer.index_name} here...",
+                                value=self.index
+                               )
+        else:
+            return dbc.Input(id=self.name, placeholder=f"Type {self.explainer.index_name} here...", 
+                             value=self.index, debounce=True, type="text")
+        
+    def component_callbacks(self, app):
+        if not self.index_dropdown:
+            @app.callback(
+                [Output(self.name, 'valid'),
+                 Output(self.name, 'invalid')],
+                [Input(self.name, 'value')]
+            )
+            def update_valid_index(index):
+                if index is not None:
+                    if self.explainer.index_exists(index):
+                        return True, False
+                    else:
+                        return False, True
+                return False, False
+                
+
 class GraphPopout(ExplainerComponent):
     """Provides a way to open a modal popup with the content of a graph figure.
 
