@@ -3,7 +3,6 @@ import unittest
 import pandas as pd
 import numpy as np
 
-from sklearn.metrics import r2_score, roc_auc_score
 
 from xgboost import XGBClassifier, XGBRegressor
 from lightgbm.sklearn import LGBMClassifier, LGBMRegressor
@@ -24,35 +23,27 @@ class XGBRegressionTests(unittest.TestCase):
         model = XGBRegressor()
         model.fit(X_train, y_train)
         self.explainer = RegressionExplainer(model, X_test, y_test, 
-                                        cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
-                                                'Deck', 'Embarked'],
-                                        units="$")
+                            cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
+                                    'Deck', 'Embarked'],
+                            units="$")
 
     def test_preds(self):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
-
-    # @unittest.expectedFailure
-    # def test_shap_interaction_values(self):
-    #     self.assertIsInstance(self.explainer.shap_interaction_values, np.ndarray)
-    #     self.assertIsInstance(self.explainer.shap_interaction_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -74,7 +65,7 @@ class LGBMRegressionTests(unittest.TestCase):
 
         model = LGBMRegressor()
         model.fit(X_train, y_train)
-        self.explainer = RegressionExplainer(model, X_test, y_test, r2_score, 
+        self.explainer = RegressionExplainer(model, X_test, y_test, 
                                         shap='tree', 
                                         cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
                                                 'Deck', 'Embarked'],
@@ -84,29 +75,22 @@ class LGBMRegressionTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
-
-    # def test_shap_interaction_values(self):
-    #     self.assertIsInstance(self.explainer.shap_interaction_values, np.ndarray)
-    #     self.assertIsInstance(self.explainer.shap_interaction_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
-        self.explainer.calculate_properties(include_interactions=True)
+        self.explainer.calculate_properties(include_interactions=False)
 
     def test_pdp_df(self):
         self.assertIsInstance(self.explainer.pdp_df("Age"), pd.DataFrame)
@@ -115,6 +99,7 @@ class LGBMRegressionTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.pdp_df("Age", index=0), pd.DataFrame)
         self.assertIsInstance(self.explainer.pdp_df("Gender", index=0), pd.DataFrame)
 
+
 class CatBoostRegressionTests(unittest.TestCase):
     def setUp(self):
         X_train, y_train, X_test, y_test = titanic_fare()
@@ -123,10 +108,10 @@ class CatBoostRegressionTests(unittest.TestCase):
         train_names, test_names = titanic_names()
         _, self.names = titanic_names()
 
-        model = CatBoostRegressor(iterations=100, learning_rate=0.1, verbose=0)
+        model = CatBoostRegressor(iterations=5, learning_rate=0.1, verbose=0)
         model.fit(X_train, y_train)
 
-        self.explainer = RegressionExplainer(model, X_test, y_test, r2_score, 
+        self.explainer = RegressionExplainer(model, X_test, y_test,
                                         cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
                                                 'Deck', 'Embarked'],
                                         idxs=test_names, units="$")
@@ -135,27 +120,19 @@ class CatBoostRegressionTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
-
-    # @unittest.expectedFailure
-    # def test_shap_interaction_values(self):
-    #     self.assertIsInstance(self.explainer.shap_interaction_values, np.ndarray)
-    #     self.assertIsInstance(self.explainer.shap_interaction_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -186,35 +163,28 @@ class XGBCLassifierTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_pred_probas(self):
-        self.assertIsInstance(self.explainer.pred_probas, np.ndarray)
+        self.assertIsInstance(self.explainer.pred_probas(), np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_shap_values_all_probabilities(self):
-        self.assertTrue(self.explainer.shap_base_value >= 0)
-        self.assertTrue(self.explainer.shap_base_value <= 1)
-        self.assertTrue(np.all(self.explainer.shap_values.sum(axis=1) + self.explainer.shap_base_value >= 0))
-        self.assertTrue(np.all(self.explainer.shap_values.sum(axis=1) + self.explainer.shap_base_value <= 1))
-
-    # def test_shap_interaction_values(self):
-    #     self.assertIsInstance(self.explainer.shap_interaction_values, np.ndarray)
-    #     self.assertIsInstance(self.explainer.shap_interaction_values_cats, np.ndarray)
+        self.assertTrue(self.explainer.shap_base_value() >= 0)
+        self.assertTrue(self.explainer.shap_base_value() <= 1)
+        self.assertTrue(np.all(self.explainer.get_shap_values_df().sum(axis=1) + self.explainer.shap_base_value() >= 0))
+        self.assertTrue(np.all(self.explainer.get_shap_values_df().sum(axis=1) + self.explainer.shap_base_value() <= 1))
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -231,15 +201,16 @@ class XGBCLassifierTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.metrics(cutoff=0.9), dict)
 
     def test_precision_df(self):
-        self.assertIsInstance(self.explainer.precision_df(), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(multiclass=True), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(quantiles=4), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(multiclass=True), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(quantiles=4), pd.DataFrame)
 
     def test_lift_curve_df(self):
-        self.assertIsInstance(self.explainer.lift_curve_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_liftcurve_df(), pd.DataFrame)
+
+    def test_prediction_result_df(self):
+        self.assertIsInstance(self.explainer.prediction_result_df(0), pd.DataFrame)
 
-    def test_prediction_result_markdown(self):
-        self.assertIsInstance(self.explainer.prediction_result_markdown(0), str)
 
 
 class LGBMClassifierTests(unittest.TestCase):
@@ -251,7 +222,7 @@ class LGBMClassifierTests(unittest.TestCase):
         model.fit(X_train, y_train)
 
         self.explainer = ClassifierExplainer(
-                            model, X_test, y_test, roc_auc_score, 
+                            model, X_test, y_test, 
                             cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
                                                 'Deck', 'Embarked'],
                             labels=['Not survived', 'Survived'],
@@ -261,36 +232,28 @@ class LGBMClassifierTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_pred_probas(self):
-        self.assertIsInstance(self.explainer.pred_probas, np.ndarray)
+        self.assertIsInstance(self.explainer.pred_probas(), np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
-
-    # @unittest.expectedFailure
-    # def test_shap_interaction_values(self):
-    #     self.assertIsInstance(self.explainer.shap_interaction_values, np.ndarray)
-    #     self.assertIsInstance(self.explainer.shap_interaction_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
     def test_shap_values_all_probabilities(self):
-        self.assertTrue(self.explainer.shap_base_value >= 0)
-        self.assertTrue(self.explainer.shap_base_value <= 1)
-        self.assertTrue(np.all(self.explainer.shap_values.sum(axis=1) + self.explainer.shap_base_value >= 0))
-        self.assertTrue(np.all(self.explainer.shap_values.sum(axis=1) + self.explainer.shap_base_value <= 1))
+        self.assertTrue(self.explainer.shap_base_value() >= 0)
+        self.assertTrue(self.explainer.shap_base_value() <= 1)
+        self.assertTrue(np.all(self.explainer.get_shap_values_df().sum(axis=1) + self.explainer.shap_base_value() >= 0))
+        self.assertTrue(np.all(self.explainer.get_shap_values_df().sum(axis=1) + self.explainer.shap_base_value() <= 1))
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -307,15 +270,16 @@ class LGBMClassifierTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.metrics(cutoff=0.9), dict)
 
     def test_precision_df(self):
-        self.assertIsInstance(self.explainer.precision_df(), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(multiclass=True), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(quantiles=4), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(multiclass=True), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(quantiles=4), pd.DataFrame)
 
     def test_lift_curve_df(self):
-        self.assertIsInstance(self.explainer.lift_curve_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_liftcurve_df(), pd.DataFrame)
+
+    def test_prediction_result_df(self):
+        self.assertIsInstance(self.explainer.prediction_result_df(0), pd.DataFrame)
 
-    def test_prediction_result_markdown(self):
-        self.assertIsInstance(self.explainer.prediction_result_markdown(0), str)
 
 
 class CatBoostClassifierTests(unittest.TestCase):
@@ -327,7 +291,7 @@ class CatBoostClassifierTests(unittest.TestCase):
         model.fit(X_train, y_train)
 
         self.explainer = ClassifierExplainer(
-                            model, X_test, y_test, roc_auc_score, 
+                            model, X_test, y_test, 
                             cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
                                                 'Deck', 'Embarked'],
                             labels=['Not survived', 'Survived'],
@@ -337,36 +301,28 @@ class CatBoostClassifierTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.preds, np.ndarray)
 
     def test_pred_probas(self):
-        self.assertIsInstance(self.explainer.pred_probas, np.ndarray)
+        self.assertIsInstance(self.explainer.pred_probas(), np.ndarray)
 
     def test_permutation_importances(self):
-        self.assertIsInstance(self.explainer.permutation_importances, pd.DataFrame)
-        self.assertIsInstance(self.explainer.permutation_importances_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_permutation_importances_df(), pd.DataFrame)
 
     def test_shap_base_value(self):
-        self.assertIsInstance(self.explainer.shap_base_value, (np.floating, float))
-
-    def test_shap_values_all_probabilities(self):
-        self.assertTrue(self.explainer.shap_base_value >= 0)
-        self.assertTrue(self.explainer.shap_base_value <= 1)
-        self.assertTrue(np.all(self.explainer.shap_values.sum(axis=1) + self.explainer.shap_base_value >= 0))
-        self.assertTrue(np.all(self.explainer.shap_values.sum(axis=1) + self.explainer.shap_base_value <= 1))
+        self.assertIsInstance(self.explainer.shap_base_value(), (np.floating, float))
 
     def test_shap_values_shape(self):
-        self.assertTrue(self.explainer.shap_values.shape == (len(self.explainer), len(self.explainer.columns)))
+        self.assertTrue(self.explainer.get_shap_values_df().shape == (len(self.explainer), len(self.explainer.merged_cols)))
 
     def test_shap_values(self):
-        self.assertIsInstance(self.explainer.shap_values, np.ndarray)
-        self.assertIsInstance(self.explainer.shap_values_cats, np.ndarray)
+        self.assertIsInstance(self.explainer.get_shap_values_df(), pd.DataFrame)
 
-    # @unittest.expectedFailure
-    # def test_shap_interaction_values(self):
-    #     self.assertIsInstance(self.explainer.shap_interaction_values, np.ndarray)
-    #     self.assertIsInstance(self.explainer.shap_interaction_values_cats, np.ndarray)
+    def test_shap_values_all_probabilities(self):
+        self.assertTrue(self.explainer.shap_base_value() >= 0)
+        self.assertTrue(self.explainer.shap_base_value() <= 1)
+        self.assertTrue(np.all(self.explainer.get_shap_values_df().sum(axis=1) + self.explainer.shap_base_value() >= 0))
+        self.assertTrue(np.all(self.explainer.get_shap_values_df().sum(axis=1) + self.explainer.shap_base_value() <= 1))
 
     def test_mean_abs_shap(self):
-        self.assertIsInstance(self.explainer.mean_abs_shap, pd.DataFrame)
-        self.assertIsInstance(self.explainer.mean_abs_shap_cats, pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_mean_abs_shap_df(), pd.DataFrame)
 
     def test_calculate_properties(self):
         self.explainer.calculate_properties(include_interactions=False)
@@ -383,15 +339,16 @@ class CatBoostClassifierTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.metrics(cutoff=0.9), dict)
 
     def test_precision_df(self):
-        self.assertIsInstance(self.explainer.precision_df(), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(multiclass=True), pd.DataFrame)
-        self.assertIsInstance(self.explainer.precision_df(quantiles=4), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(multiclass=True), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_precision_df(quantiles=4), pd.DataFrame)
 
     def test_lift_curve_df(self):
-        self.assertIsInstance(self.explainer.lift_curve_df(), pd.DataFrame)
+        self.assertIsInstance(self.explainer.get_liftcurve_df(), pd.DataFrame)
+
+    def test_prediction_result_df(self):
+        self.assertIsInstance(self.explainer.prediction_result_df(0), pd.DataFrame)
 
-    def test_prediction_result_markdown(self):
-        self.assertIsInstance(self.explainer.prediction_result_markdown(0), str)
 
 
         
\ No newline at end of file
